@@ -8,10 +8,14 @@
 #     FALSE - same as function(x) sort(unique(x))
 
 ref.grid <- function(object, at, cov.reduce = mean, mult.name, mult.levs, 
-                     options = get.lsm.option("ref.grid"), data, type, 
+                     options = get.lsm.option("ref.grid"), data, df, type, 
                      transform = c("none", "response", "log"), ...) 
 {
     transform = match.arg(transform)
+    if (!missing(df)) {
+        if(is.null(options)) options = list()
+        options$df = df
+    }
     
     # recover the data
     if (missing(data)) {
@@ -28,10 +32,8 @@ ref.grid <- function(object, at, cov.reduce = mean, mult.name, mult.levs,
     
     trms = attr(data, "terms")
     
-    # find out if any variables are coerced to factors
-    ### OLD VERSION: anm = all.names(attr(data, "terms"))    
-    ###              coerced = anm[1 + grep("factor|ordered", anm)]
-    coerced = .find.coerced(trms, data)
+    # find out if any variables are coerced to factors or vice versa
+    coerced = .find.coerced(trms, data) # now list with members 'factors' and 'covariates'
     
     # convenience function
     sort.unique = function(x) sort(unique(x))
@@ -91,16 +93,16 @@ ref.grid <- function(object, at, cov.reduce = mean, mult.name, mult.levs,
         x = data[[nm]]
         
         # Save the original levels of factors, no matter what
-        if (is.factor(x))
+        if (is.factor(x) && !(nm %in% coerced$covariates))
             xlev[[nm]] = levels(factor(x))
             # (applying factor drops any unused levels)
     
         # Now go thru and find reference levels...
-        # mentioned in 'at' list but not coerced
-        if (!(nm %in% coerced) && !missing(at) && (hasName(at, nm)))
+        # mentioned in 'at' list but not coerced factor
+        if (!(nm %in% coerced$factors) && !missing(at) && (hasName(at, nm)))
             ref.levels[[nm]] = at[[nm]]
         # factors not in 'at'
-        else if (is.factor(x))
+        else if (is.factor(x) && !(nm %in% coerced$covariates))
             ref.levels[[nm]] = levels(factor(x))
         else if (is.character(x))
             ref.levels[[nm]] = sort.unique(x)
@@ -116,12 +118,12 @@ ref.grid <- function(object, at, cov.reduce = mean, mult.name, mult.levs,
         else {
             # single numeric pred but coerced to a factor - use unique values
             # even if in 'at' list. We'll fix this up later
-            if (nm %in% coerced)            
+            if (nm %in% coerced$factors)            
                 ref.levels[[nm]] = sort.unique(x)
             
             # Ordinary covariates - summarize
             else 
-                ref.levels[[nm]] = cr(x, nm)
+                ref.levels[[nm]] = cr(as.numeric(x), nm)
         }
     }
     
@@ -145,16 +147,19 @@ ref.grid <- function(object, at, cov.reduce = mean, mult.name, mult.levs,
     
     misc = basis$misc
     
-    form = attr(data, "call")$formula
-    if (is.null(misc$tran) && (length(form) > 2)) { # No link fcn, but response may be transformed
-        lhs = form[-3] ####form[[2]]
+    ### Figure out if there is a response transformation...
+    # next stmt assumes that model formula is 1st argument (2nd element) in call.
+    # if not, we probably get an error or something that isn't a formula
+    # and it is silently ignored
+    lhs = try(eval(attr(data, "call")[[2]][-3]), silent = TRUE)
+    if (is.null(misc$tran) && (inherits(lhs, "formula"))) { # No link fcn, but response may be transformed
         tran = setdiff(.all.vars(lhs, functions = TRUE), c(.all.vars(lhs), "~", "cbind"))
         if(length(tran) > 0) {
             tran = paste(tran, collapse = ".")  
             # length > 1: Almost certainly unsupported, but facilitates a more informative error message
             
             # Look for a multiplier, e.g. 2*sqrt(y)
-            tst = strsplit(strsplit(as.character(form[2]), "\\(")[[1]][1], "\\*")[[1]]
+            tst = strsplit(strsplit(as.character(lhs[2]), "\\(")[[1]][1], "\\*")[[1]]
             if(length(tst) > 1) {
                 mul = suppressWarnings(as.numeric(tst[1]))
                 if(!is.na(mul))
@@ -202,7 +207,7 @@ ref.grid <- function(object, at, cov.reduce = mean, mult.name, mult.levs,
 # So we now need to subset the rows of the grid and linfct based on 'at'
 
     problems = if (!missing(at)) 
-        intersect(c(multresp, coerced), names(at)) 
+        intersect(c(multresp, coerced$factors), names(at)) 
     else character(0)
     if (length(problems > 0)) {
         incl.flags = rep(TRUE, nrow(grid))
@@ -237,7 +242,7 @@ ref.grid <- function(object, at, cov.reduce = mean, mult.name, mult.levs,
     ### --- Determine weights for each grid point --- (added ver.2.11), updated ver.2.14 to include weights
     if (!hasName(data, "(weights)"))
         data[["(weights)"]] = 1
-    nms = union(names(xlev), coerced) # only factors, no covariates or mult.resp
+    nms = union(names(xlev), coerced$factors) # only factors, no covariates or mult.resp
     # originally, I used 'plyr::count', but there are probs when there is a 'freq' variable
     id = plyr::id(data[, nms, drop = FALSE], drop = TRUE)
     uid = !duplicated(id)
@@ -314,8 +319,8 @@ ref.grid <- function(object, at, cov.reduce = mean, mult.name, mult.levs,
 
 
 # This function figures out which covariates in a model 
-# have been coerced to factors. Does NOT rely on the names of
-# functions like 'factor' or 'interaction' as we use actual results
+# have been coerced to factors. And also which factors have been coerced
+# to be covariates
 .find.coerced = function(trms, data) {
     isfac = sapply(data, function(x) inherits(x, "factor"))
     
@@ -328,19 +333,25 @@ ref.grid <- function(object, at, cov.reduce = mean, mult.name, mult.levs,
     isfac = sapply(M, function(x) inherits(x, "factor"))
     
     # Character vector of terms in the model frame that are factors ...
-    facs.m = names(M)[isfac]
+    facs.m = names(M)[as.logical(isfac)]
+    covs.m = setdiff(names(M), facs.m)
     
     # Exclude the terms that are already factors
     # What's left will be things like "factor(dose)", "interact(dose,treat)", etc
-    cterms = setdiff(facs.m, facs.d)
+    cfac = setdiff(facs.m, facs.d)
+    if(length(cfac) != 0) {
+        cvars = lapply(cfac, function(x) .all.vars(reformulate(x))) # Strip off the function calls
+        cfac = intersect(unique(unlist(cvars)), covs.d) # Exclude any variables that are already factors
+    }
     
-    if(length(cterms) == 0) 
-        return(cterms)
-    # (else) Strip off the function calls
-    cvars = lapply(cterms, function(x) .all.vars(reformulate(x)))
+    # Do same with covariates
+    ccov = setdiff(covs.m, covs.d)
+    if(length(ccov) > 0) {
+        cvars = lapply(ccov, function(x) .all.vars(reformulate(x)))
+        ccov = intersect(unique(unlist(cvars)), facs.d)
+    }
     
-    # Exclude any variables that are already factors
-    intersect(unique(unlist(cvars)), covs.d)
+    list(factors = cfac, covariates = ccov)
 }
 
 # calculate the offset for the given grid
@@ -466,7 +477,10 @@ lsm.options = function(...) {
     for (nm in names(newopts))
         opts[[nm]] = newopts[[nm]]
     options(lsmeans = opts)
-    invisible(opts)
+    if (length(newopts) > 0)
+        invisible(opts)
+    else
+        opts
 }
 
 # equivalent of getOption()
@@ -481,7 +495,7 @@ get.lsm.option = function(x, default = defaults.lsm[[x]]) {
 ### Exported defaults for certain options
 defaults.lsm = list(
     estble.tol = 1e-8,        # tolerance for estimability checks
-    disable.satterth = TRUE,  # for now, keep the old K-R method as default
+    lmer.df = "satterth",     # Use Satterthwaite method for df
     disable.pbkrtest = FALSE, # whether to bypass pbkrtest routines for lmerMod
     pbkrtest.limit = 3000,    # limit on N for enabling adj V
     save.ref.grid = TRUE      # save new ref.grid in .Last.ref.grid
